@@ -408,6 +408,13 @@ class TestPath(unittest.TestCase):
         e = root / '.hgrc'
         assert e.suffixes == []
 
+    @pass_alpharep
+    def test_suffix_no_filename(self, alpharep):
+        alpharep.filename = None
+        root = zipp.Path(alpharep)
+        assert root.joinpath('example').suffix == ""
+        assert root.joinpath('example').suffixes == []
+
     @pass_alpharep
     def test_stem(self, alpharep):
         """
@@ -425,6 +432,8 @@ class TestPath(unittest.TestCase):
         d = root / "d"
         assert d.stem == "d"
 
+        assert (root / ".gitignore").stem == ".gitignore"
+
     @pass_alpharep
     def test_root_parent(self, alpharep):
         root = zipp.Path(alpharep)
